translate.search.indexing.XapianIndexer.XapianEnquire

Package translate :: Package search :: Package indexing :: Module XapianIndexer :: Class XapianEnquire |
[hide private]
[frames] | no frames]

# Class XapianEnquire

source code

interface to the xapian object for storing sets of matches

Instance Methods | [hide private]
tuple of (returned number, available number, matches) "matches" is a dictionary of:
       ["rank", "percent", "document", "docid"]
get_matches(self, start, number) return a specified number of qualified matches of a previous query | source code
Inherited from `CommonIndexer.CommonEnquire`: `__init__`, `get_matches_count` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### get_matches(self, start, number) | source code
return a specified number of qualified matches of a previous query Parameters: `start` (int) - index of the first match to return (starting from zero) `number` (int) - the number of matching entries to return Returns: tuple of (returned number, available number, matches) "matches" is a dictionary of:
       ["rank", "percent", "document", "docid"]
a set of matching entries and some statistics Overrides: CommonIndexer.CommonEnquire.get_matches